Timber v2.8.4 Timber.Events.ChannelJoinEvent View Source
The ChannelJoinEvent represents a web socket channel topic being joined.
The defined structure of this data can be found in the log event JSON schema: https://github.com/timberio/log-event-json-schema
Link to this section Summary
Link to this section Types
Link to this section Functions
Message to be used when logging.
Builds a new struct taking care to:
- Converts
:paramsto:params_jsonthat satifies the Timber API requirements