Timber v3.1.2 Timber.Events.HTTPRequestEvent View Source
DEPRECATED
The Timber.Events.HTTPRequestEvent module is deprecated in favor of using maps.
The next evolution of Timber (2.0) no long requires a strict schema and therefore simplifies how users log events.
To easily migrate, please install the :timber_plug library:
https://github.com/timberio/timber-elixir-plug
Link to this section Summary
Link to this section Types
Link to this type
t()
t()
t() :: %Timber.Events.HTTPRequestEvent{
body: String.t() | nil,
direction: String.t() | nil,
headers: map() | nil,
headers_json: String.t() | nil,
host: String.t() | nil,
method: String.t(),
path: String.t() | nil,
port: pos_integer() | nil,
query_string: String.t() | nil,
request_id: String.t() | nil,
scheme: String.t() | nil,
service_name: nil | String.t()
}
t() :: %Timber.Events.HTTPRequestEvent{
body: String.t() | nil,
direction: String.t() | nil,
headers: map() | nil,
headers_json: String.t() | nil,
host: String.t() | nil,
method: String.t(),
path: String.t() | nil,
port: pos_integer() | nil,
query_string: String.t() | nil,
request_id: String.t() | nil,
scheme: String.t() | nil,
service_name: nil | String.t()
}