Timber v3.1.2 Timber.LoggerBackends.InMemory View Source
Logger backend for testing only
This implement a custom Logger backend for integration testing when
implementing code dependent on the Timber library. This module can be used to
verify events sent with Logger.
To account for the asynchronous nature of Logger, a process ID can be
registered with the backend. When an event is received, the message :ok will
be sent to the corresponding process.